@@ -617,13 +617,15 @@ class RedisRoot:
             print(f'{datetime.datetime.now()} - '
                   f'Cached {django_model} successfully'
                   f'\n\n\n')
-            for func_name, performance_data in self.performance.items():
-                if func_name != 'enabled':
-                    print(f'\n'
-                          f'{func_name}'
-                          f'Requests: {performance_data["requests"]}\n'
-                          f'Time: {performance_data["time"]}s\n'
-                          f'Per request: {performance_data["time"]/performance_data["requests"]}s')
+            if self.performance['enabled']:
+                print('Performance')
+                for func_name, performance_data in self.performance.items():
+                    if func_name != 'enabled':
+                        print(f'\n'
+                              f'{func_name}\n'
+                              f'Requests: {performance_data["requests"]}\n'
+                              f'Time: {performance_data["time"]}s\n'
+                              f'Per request: {performance_data["time"]/performance_data["requests"]}s')
 
 
     def fast_get_keys_values(self, string):
@@ -919,6 +921,15 @@ class RedisRoot:
         return allowed
 
     def _get_instances_by_key(self, key):
+        if self.performance['enabled']:
+            if '_get_instances_by_key' not in self.performance.keys():
+                self.performance['_get_instances_by_key'] = {
+                    'requests': 0,
+                    'time': 0
+                }
+            self.performance['_get_instances_by_key']['requests'] += 1
+            started_in = datetime.datetime.now()
+
         raw_instances = self.fast_get_keys_values(key)
         instances = {}
         for instance_key, fields_json in raw_instances.items():
@@ -930,6 +941,9 @@ class RedisRoot:
                 if instance_id not in instances.keys():
                     instances[instance_id] = {}
                 instances[instance_id][field_name] = value
+        if self.performance['enabled']:
+            ended_in = datetime.datetime.now()
+            self.performance['_get_instances_by_key']['time'] += (ended_in - started_in).total_seconds()
         return instances
 
     def _get_all_stored_model_instances(self, redis_model, filters=None):
@@ -1124,8 +1138,20 @@ class RedisRoot:
     #     return result
 
     def create(self, django_model, **params):
+        if self.performance['enabled']:
+            if 'create' not in self.performance.keys():
+                self.performance['create'] = {
+                    'requests': 0,
+                    'time': 0
+                }
+            self.performance['create']['requests'] += 1
+            started_in = datetime.datetime.now()
+
         redis_model = self._django_model_to_redis_model(django_model)
         redis_instance = redis_model(redis_root=self, **params).save()
+        if self.performance['enabled']:
+            ended_in = datetime.datetime.now()
+            self.performance['create']['time'] += (ended_in - started_in).total_seconds()
         return redis_instance
 
 
