@@ -837,7 +837,7 @@ class RedisRoot:
                 }
         return instances
 
-    def _get_all_model_instances(self, redis_model, filters=None):
+    def _get_all_redis_model_instances(self, redis_model, filters=None):
         if filters is None:
             filters = {}
         instances_with_allowed = self._get_all_redis_instances(redis_model, filters)
